@@ -826,9 +826,8 @@ def set(inputs,outputs,count=0,table='',overwrite=False,launch=False,log=True,de
         content_len
         queue = inputs.QUEUE.drop_duplicates()
         dif = content_len - queue.shape[0]
-        if log:
-            click.secho(f"Removed {dif} duplicate cases from queue.",color='bright_yellow',bold=True)
         if debug:
+            click.secho(f"Removed {dif} duplicate cases from queue.",color='bright_yellow',bold=True)
             click.secho(queue)
     else:
         queue = inputs.QUEUE
@@ -1309,6 +1308,7 @@ def getCharges(text: str):
     passed = pd.Series(passed.tolist())
     passed = passed.map(lambda x: re.sub(r'(\s+[0-1]{1}$)', '',x))
     passed = passed.map(lambda x: re.sub(r'([©|\w]{1}[a-z]+)', ' ',x))
+    passed = passed.map(lambda x: re.sub(r'(0\.0[0\s]\s+$)', ' ',x))
     passed = passed.explode()
     c = passed.dropna().tolist()
     cind = range(0, len(c))
